"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.product_sync
from eis.product_sync.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check(self):
        """Test case for check

        Health Check  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from eis.product_sync.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from eis.product_sync.model.create_product_request_dto import CreateProductRequestDto
from eis.product_sync.model.create_product_response_class import CreateProductResponseClass
from eis.product_sync.model.create_product_version_request_dto import CreateProductVersionRequestDto
from eis.product_sync.model.create_product_version_response_class import CreateProductVersionResponseClass
from eis.product_sync.model.get_environment_info_response_class import GetEnvironmentInfoResponseClass
from eis.product_sync.model.get_task_product_details_response_class import GetTaskProductDetailsResponseClass
from eis.product_sync.model.get_task_status_response_class import GetTaskStatusResponseClass
from eis.product_sync.model.inline_response200 import InlineResponse200
from eis.product_sync.model.inline_response503 import InlineResponse503
from eis.product_sync.model.list_products_response_class import ListProductsResponseClass
from eis.product_sync.model.list_task_logs_response_class import ListTaskLogsResponseClass
from eis.product_sync.model.list_tasks_response_class import ListTasksResponseClass
from eis.product_sync.model.product_class import ProductClass
from eis.product_sync.model.product_version_class import ProductVersionClass
from eis.product_sync.model.start_compare_task_request_dto import StartCompareTaskRequestDto
from eis.product_sync.model.start_compare_task_response_class import StartCompareTaskResponseClass
from eis.product_sync.model.start_copy_task_request_dto import StartCopyTaskRequestDto
from eis.product_sync.model.start_copy_task_response_class import StartCopyTaskResponseClass
from eis.product_sync.model.start_export_task_request_dto import StartExportTaskRequestDto
from eis.product_sync.model.start_export_task_response_class import StartExportTaskResponseClass
from eis.product_sync.model.start_sync_task_request_dto import StartSyncTaskRequestDto
from eis.product_sync.model.start_sync_task_response_class import StartSyncTaskResponseClass
from eis.product_sync.model.stop_task_request_dto import StopTaskRequestDto
from eis.product_sync.model.stop_task_response_class import StopTaskResponseClass
from eis.product_sync.model.task_class import TaskClass
from eis.product_sync.model.task_log_class import TaskLogClass



"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.product_sync
from eis.product_sync.api.tasks_api import TasksApi  # noqa: E501


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_task_product_details(self):
        """Test case for get_task_product_details

        Retrieve the Task product details  # noqa: E501
        """
        pass

    def test_get_task_status(self):
        """Test case for get_task_status

        Retrieve the Task status  # noqa: E501
        """
        pass

    def test_list_task_logs(self):
        """Test case for list_task_logs

        List Tasks  # noqa: E501
        """
        pass

    def test_list_tasks(self):
        """Test case for list_tasks

        List Tasks  # noqa: E501
        """
        pass

    def test_start_compare_task(self):
        """Test case for start_compare_task

        Create the compare  # noqa: E501
        """
        pass

    def test_start_copy_task(self):
        """Test case for start_copy_task

        Create the copy  # noqa: E501
        """
        pass

    def test_start_export_task(self):
        """Test case for start_export_task

        Create the export  # noqa: E501
        """
        pass

    def test_start_sync_task(self):
        """Test case for start_sync_task

        Create the sync  # noqa: E501
        """
        pass

    def test_stop_task(self):
        """Test case for stop_task

        Update the stop  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.product_sync
from eis.product_sync.model.task_class import TaskClass
globals()['TaskClass'] = TaskClass
from eis.product_sync.model.start_compare_task_response_class import StartCompareTaskResponseClass


class TestStartCompareTaskResponseClass(unittest.TestCase):
    """StartCompareTaskResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStartCompareTaskResponseClass(self):
        """Test StartCompareTaskResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StartCompareTaskResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.product_sync
from eis.product_sync.model.start_copy_task_request_dto import StartCopyTaskRequestDto


class TestStartCopyTaskRequestDto(unittest.TestCase):
    """StartCopyTaskRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStartCopyTaskRequestDto(self):
        """Test StartCopyTaskRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StartCopyTaskRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.product_sync.api_client import ApiClient, Endpoint as _Endpoint
from eis.product_sync.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.product_sync.model.get_task_product_details_response_class import GetTaskProductDetailsResponseClass
from eis.product_sync.model.get_task_status_response_class import GetTaskStatusResponseClass
from eis.product_sync.model.list_task_logs_response_class import ListTaskLogsResponseClass
from eis.product_sync.model.list_tasks_response_class import ListTasksResponseClass
from eis.product_sync.model.start_compare_task_request_dto import StartCompareTaskRequestDto
from eis.product_sync.model.start_compare_task_response_class import StartCompareTaskResponseClass
from eis.product_sync.model.start_copy_task_request_dto import StartCopyTaskRequestDto
from eis.product_sync.model.start_copy_task_response_class import StartCopyTaskResponseClass
from eis.product_sync.model.start_export_task_request_dto import StartExportTaskRequestDto
from eis.product_sync.model.start_export_task_response_class import StartExportTaskResponseClass
from eis.product_sync.model.start_sync_task_request_dto import StartSyncTaskRequestDto
from eis.product_sync.model.start_sync_task_response_class import StartSyncTaskResponseClass
from eis.product_sync.model.stop_task_request_dto import StopTaskRequestDto
from eis.product_sync.model.stop_task_response_class import StopTaskResponseClass


class TasksApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_task_product_details_endpoint = _Endpoint(
            settings={
                'response_type': (GetTaskProductDetailsResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/{taskUid}/details/{entityType}',
                'operation_id': 'get_task_product_details',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'task_uid',
                    'entity_type',
                    'parent_name',
                    'authorization',
                ],
                'required': [
                    'task_uid',
                    'entity_type',
                    'parent_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'task_uid':
                        (str,),
                    'entity_type':
                        (str,),
                    'parent_name':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'task_uid': 'taskUid',
                    'entity_type': 'entityType',
                    'parent_name': 'parentName',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'task_uid': 'path',
                    'entity_type': 'path',
                    'parent_name': 'query',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_task_status_endpoint = _Endpoint(
            settings={
                'response_type': (GetTaskStatusResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/{taskUid}/status',
                'operation_id': 'get_task_status',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'task_uid',
                    'authorization',
                ],
                'required': [
                    'task_uid',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'task_uid':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'task_uid': 'taskUid',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'task_uid': 'path',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_task_logs_endpoint = _Endpoint(
            settings={
                'response_type': (ListTaskLogsResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/logs',
                'operation_id': 'list_task_logs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'authorization',
                    'page_size',
                    'page_token',
                    'filter',
                    'search',
                    'order',
                    'expand',
                    'filters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'authorization':
                        (str,),
                    'page_size':
                        (float,),
                    'page_token':
                        (str,),
                    'filter':
                        (str,),
                    'search':
                        (str,),
                    'order':
                        (str,),
                    'expand':
                        (str,),
                    'filters':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'filter': 'filter',
                    'search': 'search',
                    'order': 'order',
                    'expand': 'expand',
                    'filters': 'filters',
                },
                'location_map': {
                    'authorization': 'header',
                    'page_size': 'query',
                    'page_token': 'query',
                    'filter': 'query',
                    'search': 'query',
                    'order': 'query',
                    'expand': 'query',
                    'filters': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_tasks_endpoint = _Endpoint(
            settings={
                'response_type': (ListTasksResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks',
                'operation_id': 'list_tasks',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'authorization',
                    'page_size',
                    'page_token',
                    'filter',
                    'search',
                    'order',
                    'expand',
                    'filters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'authorization':
                        (str,),
                    'page_size':
                        (float,),
                    'page_token':
                        (str,),
                    'filter':
                        (str,),
                    'search':
                        (str,),
                    'order':
                        (str,),
                    'expand':
                        (str,),
                    'filters':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'filter': 'filter',
                    'search': 'search',
                    'order': 'order',
                    'expand': 'expand',
                    'filters': 'filters',
                },
                'location_map': {
                    'authorization': 'header',
                    'page_size': 'query',
                    'page_token': 'query',
                    'filter': 'query',
                    'search': 'query',
                    'order': 'query',
                    'expand': 'query',
                    'filters': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.start_compare_task_endpoint = _Endpoint(
            settings={
                'response_type': (StartCompareTaskResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/start/compare',
                'operation_id': 'start_compare_task',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'start_compare_task_request_dto',
                    'authorization',
                ],
                'required': [
                    'start_compare_task_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'start_compare_task_request_dto':
                        (StartCompareTaskRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'start_compare_task_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_copy_task_endpoint = _Endpoint(
            settings={
                'response_type': (StartCopyTaskResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/start/copy',
                'operation_id': 'start_copy_task',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'start_copy_task_request_dto',
                    'authorization',
                ],
                'required': [
                    'start_copy_task_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'start_copy_task_request_dto':
                        (StartCopyTaskRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'start_copy_task_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_export_task_endpoint = _Endpoint(
            settings={
                'response_type': (StartExportTaskResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/start/export',
                'operation_id': 'start_export_task',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'start_export_task_request_dto',
                    'authorization',
                ],
                'required': [
                    'start_export_task_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'start_export_task_request_dto':
                        (StartExportTaskRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'start_export_task_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_sync_task_endpoint = _Endpoint(
            settings={
                'response_type': (StartSyncTaskResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/start/sync',
                'operation_id': 'start_sync_task',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'start_sync_task_request_dto',
                    'authorization',
                ],
                'required': [
                    'start_sync_task_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'start_sync_task_request_dto':
                        (StartSyncTaskRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'start_sync_task_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.stop_task_endpoint = _Endpoint(
            settings={
                'response_type': (StopTaskResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/productsyncservice/v1/tasks/stop',
                'operation_id': 'stop_task',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'stop_task_request_dto',
                    'authorization',
                ],
                'required': [
                    'stop_task_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'stop_task_request_dto':
                        (StopTaskRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'stop_task_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_task_product_details(
        self,
        task_uid,
        entity_type,
        parent_name,
        **kwargs
    ):
        """Retrieve the Task product details  # noqa: E501

        Retrieves the details of the Task product details that was previously created. Supply the unique Task product details code      that was returned when you created it and Emil Api will return the corresponding Task product details information.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_task_product_details(task_uid, entity_type, parent_name, async_req=True)
        >>> result = thread.get()

        Args:
            task_uid (str):
            entity_type (str):
            parent_name (str):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetTaskProductDetailsResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['task_uid'] = \
            task_uid
        kwargs['entity_type'] = \
            entity_type
        kwargs['parent_name'] = \
            parent_name
        return self.get_task_product_details_endpoint.call_with_http_info(**kwargs)

    def get_task_status(
        self,
        task_uid,
        **kwargs
    ):
        """Retrieve the Task status  # noqa: E501

        Retrieves the details of the Task status that was previously created. Supply the unique Task status code      that was returned when you created it and Emil Api will return the corresponding Task status information.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_task_status(task_uid, async_req=True)
        >>> result = thread.get()

        Args:
            task_uid (str):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetTaskStatusResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['task_uid'] = \
            task_uid
        return self.get_task_status_endpoint.call_with_http_info(**kwargs)

    def list_task_logs(
        self,
        **kwargs
    ):
        """List Tasks  # noqa: E501

        Returns a list of Tasks you have previously created.          The Tasks are returned in sorted order, with the oldest one appearing first.          For more information about pagination, read the Pagination documentation.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_task_logs(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            page_size (float): A limit on the number of objects to be returned.     Limit ranges between 1 and 50. Default: 10.. [optional]
            page_token (str): A cursor for use in pagination.     pageToken is an ID that defines your place in the list.     For instance, if you make a list request and receive 100 objects and pageToken=1, your subsequent call can include pageToken=2 in order to fetch the next page of the list.. [optional]
            filter (str): Filter the response by one or multiple fields.            In general, fetching filtered responses will conserve bandwidth and reduce response time.<br/>           <br/>           <i>Allowed values: id, taskId, progressPct, message, isError, createdAt</i>. [optional]
            search (str): Search the response for matches in any searchable field.            Use filter instead where possible for improved performance.<br/>           <br/>           <i>Searchable fields: message</i>. [optional]
            order (str): Order allows you to specify the desired order of entities retrieved from the server by           ascending (ASC) or descending (DESC) order.<br/>           <br/>           <i>Allowed values: id, progressPct, isError, createdAt</i>. [optional]
            expand (str): Expand to fetch additional information about the list items.       Expanding resources can reduce the number of API calls required to accomplish a task.       Use with discretion as some expanded fields can drastically increase payload size.<br/>       <br/>       . [optional]
            filters (str): Filters the response by one or multiple fields.            Advanced filter functionality allows you to perform more complex filtering operations.<br/>           <br/>           <i>Allowed values: id, taskId, progressPct, message, isError, createdAt</i>. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListTaskLogsResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_task_logs_endpoint.call_with_http_info(**kwargs)

    def list_tasks(
        self,
        **kwargs
    ):
        """List Tasks  # noqa: E501

        Returns a list of Tasks you have previously created.          The Tasks are returned in sorted order, with the oldest one appearing first.          For more information about pagination, read the Pagination documentation.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_tasks(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            page_size (float): A limit on the number of objects to be returned.     Limit ranges between 1 and 50. Default: 10.. [optional]
            page_token (str): A cursor for use in pagination.     pageToken is an ID that defines your place in the list.     For instance, if you make a list request and receive 100 objects and pageToken=1, your subsequent call can include pageToken=2 in order to fetch the next page of the list.. [optional]
            filter (str): Filter the response by one or multiple fields.            In general, fetching filtered responses will conserve bandwidth and reduce response time.<br/>           <br/>           <i>Allowed values: id, code, taskUid, sourceEnv, sourceProductSlug, sourceProductVersionId, targetEnv, targetProductSlug, targetProductName, targetProductVersionId, taskType, status, progressPct, startedAt, beenStoppedAt, endedAt, error, createdBy, createdAt</i>. [optional]
            search (str): Search the response for matches in any searchable field.            Use filter instead where possible for improved performance.<br/>           <br/>           <i>Searchable fields: sourceEnv, sourceProductSlug, targetEnv, targetProductSlug, targetProductName, error, ecsTaskArn</i>. [optional]
            order (str): Order allows you to specify the desired order of entities retrieved from the server by           ascending (ASC) or descending (DESC) order.<br/>           <br/>           <i>Allowed values: id, taskUid, sourceEnv, sourceProductSlug, targetEnv, targetProductSlug, targetProductName, error, taskType, status, ecsTaskArn, createdAt</i>. [optional]
            expand (str): Expand to fetch additional information about the list items.       Expanding resources can reduce the number of API calls required to accomplish a task.       Use with discretion as some expanded fields can drastically increase payload size.<br/>       <br/>       <i>Allowed values: taskLog<i>. [optional]
            filters (str): Filters the response by one or multiple fields.            Advanced filter functionality allows you to perform more complex filtering operations.<br/>           <br/>           <i>Allowed values: id, code, taskUid, sourceEnv, sourceProductSlug, sourceProductVersionId, targetEnv, targetProductSlug, targetProductName, targetProductVersionId, taskType, status, progressPct, startedAt, beenStoppedAt, endedAt, error, createdBy, createdAt</i>. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListTasksResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_tasks_endpoint.call_with_http_info(**kwargs)

    def start_compare_task(
        self,
        start_compare_task_request_dto,
        **kwargs
    ):
        """Create the compare  # noqa: E501

        This will start compare task.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_compare_task(start_compare_task_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            start_compare_task_request_dto (StartCompareTaskRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            StartCompareTaskResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['start_compare_task_request_dto'] = \
            start_compare_task_request_dto
        return self.start_compare_task_endpoint.call_with_http_info(**kwargs)

    def start_copy_task(
        self,
        start_copy_task_request_dto,
        **kwargs
    ):
        """Create the copy  # noqa: E501

        This will start copy task.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_copy_task(start_copy_task_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            start_copy_task_request_dto (StartCopyTaskRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            StartCopyTaskResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['start_copy_task_request_dto'] = \
            start_copy_task_request_dto
        return self.start_copy_task_endpoint.call_with_http_info(**kwargs)

    def start_export_task(
        self,
        start_export_task_request_dto,
        **kwargs
    ):
        """Create the export  # noqa: E501

        This will start export task.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_export_task(start_export_task_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            start_export_task_request_dto (StartExportTaskRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            StartExportTaskResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['start_export_task_request_dto'] = \
            start_export_task_request_dto
        return self.start_export_task_endpoint.call_with_http_info(**kwargs)

    def start_sync_task(
        self,
        start_sync_task_request_dto,
        **kwargs
    ):
        """Create the sync  # noqa: E501

        This will start sync task.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_sync_task(start_sync_task_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            start_sync_task_request_dto (StartSyncTaskRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            StartSyncTaskResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['start_sync_task_request_dto'] = \
            start_sync_task_request_dto
        return self.start_sync_task_endpoint.call_with_http_info(**kwargs)

    def stop_task(
        self,
        stop_task_request_dto,
        **kwargs
    ):
        """Update the stop  # noqa: E501

        This will stop the running task.  **Required Permissions**  \"policy-management.products.view\", \"policy-management.products.create\", \"policy-management.products.update\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stop_task(stop_task_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            stop_task_request_dto (StopTaskRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            StopTaskResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['stop_task_request_dto'] = \
            stop_task_request_dto
        return self.stop_task_endpoint.call_with_http_info(**kwargs)




"""
    EMIL ProductSyncService

    The EMIL ProductSyncService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.product_sync
from eis.product_sync.api.products_api import ProductsApi  # noqa: E501


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = ProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_product(self):
        """Test case for create_product

        Create the product  # noqa: E501
        """
        pass

    def test_create_product_version(self):
        """Test case for create_product_version

        Create the version  # noqa: E501
        """
        pass

    def test_get_environment_info(self):
        """Test case for get_environment_info

        Retrieve the Environment Info  # noqa: E501
        """
        pass

    def test_list_products(self):
        """Test case for list_products

        List Products  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
